#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-GBYK1mEdxhoBueGsPTFNWh
key:                  haskell-language-server-2.3.0.0-GBYK1mEdxhoBueGsPTFNWh
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5797f2e1b3abf6c5d6658688ecc96d6b
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-GBYK1mEdxhoBueGsPTFNWh
depends:
    aeson-pretty-0.8.11-BF5xTcMyKkiDM3IwcPJ1Vo
    async-2.2.6-B1xPYkcAzs1LAdhNFIgAnG base-4.18.2.1
    base16-bytestring-1.0.2.0-LOzdqrPOAmvA9dBRBt8wdk
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-4z9YPazGkkw2elIgzmGVb2
    data-default-0.7.1.3-v65wBq6p7UHdeTWfWwzRF directory-1.3.8.5
    extra-1.7.16-DutWM4qj2UOFoGYeyZgh2s filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-5ssdDHVSHun4CTi9Kh39ZX
    githash-0.1.7.0-5KsjYGU6nh726oYx3c1jzc
    hie-bios-0.12.0-CRSGEUnL3rI1wguWImzBzV
    hiedb-0.4.3.0-9k23BwHqzOPJQgKbPlmg9n
    hls-alternate-number-format-plugin-2.3.0.0-Bv1AMYXF5yr6589Uh62Ai8
    hls-cabal-fmt-plugin-2.3.0.0-EVGyZW4cZdB17qP4FkQWPc
    hls-cabal-plugin-2.3.0.0-BG4VrpnTp5iLZcT5FN9TPQ
    hls-call-hierarchy-plugin-2.3.0.0-7pBEnRMDdbg8CL1lb8id
    hls-change-type-signature-plugin-2.3.0.0-CIeESIHzO8mDBp5mcLC70K
    hls-class-plugin-2.3.0.0-9NylHSNsu099Vbf7eg7gNB
    hls-code-range-plugin-2.3.0.0-4UKzjsBMORx9VJyZrSxHRA
    hls-eval-plugin-2.3.0.0-5ZJpUbnzPro6pAI4YcpEPk
    hls-explicit-fixity-plugin-2.3.0.0-AcnJRcytQgB5lIc78JZChy
    hls-explicit-imports-plugin-2.3.0.0-1IpJL8k1ePmHSgfjGCSZTG
    hls-explicit-record-fields-plugin-2.3.0.0-Bn7yMVggbbKAJLIMq9fvBx
    hls-fourmolu-plugin-2.3.0.0-3uENxmLM1N52bUkHxWTCtZ
    hls-gadt-plugin-2.3.0.0-9AVLBR3zJ8VGRHPV1d3k2H
    hls-graph-2.3.0.0-BKCw9wgtA1S1PhMBjmLsTw
    hls-hlint-plugin-2.3.0.0-JmkAJ5R28875bEkD6aeepN
    hls-module-name-plugin-2.3.0.0-Biivziau86Y4xrxZPKPuE
    hls-ormolu-plugin-2.3.0.0-8a9T6TCwPl5JqRUTAlx90T
    hls-overloaded-record-dot-plugin-2.3.0.0-4CL3j5n69oH7af6IUwUdDM
    hls-plugin-api-2.3.0.0-4xBXilkZH7I1XWpO94lJCk
    hls-pragmas-plugin-2.3.0.0-3BFQEcxC2VDGmqGoKJ0rHo
    hls-qualify-imported-names-plugin-2.3.0.0-7rjUjxkHyt4GqMs693Rvjs
    hls-refactor-plugin-2.3.0.0-9vZj1loq71nIU66ktyKMUw
    hls-rename-plugin-2.3.0.0-4zguDPXGGVDzN7OA79Vxg
    hls-retrie-plugin-2.3.0.0-KGg1PBXAI3zFN58BicTos
    hls-splice-plugin-2.3.0.0-KyyM74LcCOd5jjK6TD1FRo
    hls-stylish-haskell-plugin-2.3.0.0-ENZhYjwWJtoDALPqRd6Vmp
    lsp-2.2.0.0-6w4y1QddwBxGRyqRyrutmt
    optparse-applicative-0.18.1.0-JRbhqUMlTBkCWkkrIaelno
    optparse-simple-0.1.1.4-JnbdMid7imGAK2MXlOC4r5
    prettyprinter-1.7.2-HvkUgaUIGC1QRxB5LZpIj process-1.6.19.0
    safe-exceptions-0.1.7.4-2nheImLyyBWAYQkT0m3AQ1
    sqlite-simple-0.4.19.0-FodiOxVO6zNIAKXPjeRkt6 text-2.0.2
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

